@@ -13,7 +13,6 @@
 # limitations under the License.
 
 from novaclient import base
-from novaclient.openstack.common import cliutils
 from novaclient import utils
 
 
@@ -53,9 +52,9 @@ def ip_address_formatter(field):
     return ",".join(addresses)
 
 
-@cliutils.arg('instance_id', metavar='<instance_id>',
-              help="ID of the instance you want to display virtual"
-                   "interfaces for")
+@utils.arg('instance_id', metavar='<instance_id>',
+           help="ID of the instance you want to display virtual"
+                "interfaces for")
 def do_virtual_interface_list(cs, args):
     """
     Lists the virtual interfaces for an instance
@@ -66,10 +65,10 @@ def do_virtual_interface_list(cs, args):
                      formatters={"ip_addresses": ip_address_formatter})
 
 
-@cliutils.arg('network_id', metavar='<network_id>',
-              help='Network ID to connect the new virtual interface to')
-@cliutils.arg('instance_id', metavar='<instance_id>',
-              help="Instance to attach the new virtual interface to")
+@utils.arg('network_id', metavar='<network_id>',
+           help='Network ID to connect the new virtual interface to')
+@utils.arg('instance_id', metavar='<instance_id>',
+           help="Instance to attach the new virtual interface to")
 def do_virtual_interface_create(cs, args):
     """
     Add a new virtual interface to an instance
@@ -85,10 +84,10 @@ def do_virtual_interface_create(cs, args):
         utils.print_dict(addr_dict)
 
 
-@cliutils.arg('instance_id', metavar='<instance_id>',
-              help="Instance to remove the virtual interface from")
-@cliutils.arg('interface_id', metavar='<interface_id>',
-              help='ID of the virtual interface to delete')
+@utils.arg('instance_id', metavar='<instance_id>',
+           help="Instance to remove the virtual interface from")
+@utils.arg('interface_id', metavar='<interface_id>',
+           help='ID of the virtual interface to delete')
 def do_virtual_interface_delete(cs, args):
     """
     Removes the specified virtual interface from an instance
